defmodule Bump.Application do
  # See https://hexdocs.pm/elixir/Application.html
  # for more information on OTP Applications
  @moduledoc false

  use Application

  @impl true
  def start(_type, _args) do
    children = [
      # Start the Ecto repository
      Bump.Repo,
      # Start the Telemetry supervisor
      BumpWeb.Telemetry,
      # Start the PubSub system
      {Phoenix.PubSub, name: Bump.PubSub},
      # Start the Endpoint (http/https)
      BumpWeb.Endpoint,
      # Start a worker by calling: Bump.Worker.start_link(arg)
      # {Bump.Worker, arg}
      Bump.FCM
    ]

    # See https://hexdocs.pm/elixir/Supervisor.html
    # for other strategies and supported options
    opts = [strategy: :one_for_one, name: Bump.Supervisor]
    Supervisor.start_link(children, opts)

  end

  # Tell Phoenix to update the endpoint configuration
  # whenever the application is updated.
  @impl true
  def config_change(changed, _new, removed) do
    BumpWeb.Endpoint.config_change(changed, removed)
    :ok
  end
end
